@@ -4,7 +4,6 @@ use Pcore -role, -const;
 use Pcore::API::Nginx;
 use Pcore::HTTP::Server;
 use Pcore::App::Router;
-use Pcore::App::API;
 use Pcore::CDN;
 use Pcore::Util::Scalar qw[is_plain_arrayref];
 
@@ -73,9 +72,6 @@ around new => sub ( $orig, $self, $devel = undef, $runtime_cfg = undef ) {
     # create CDN object
     $self->{cdn} = Pcore::CDN->new( $self->{cfg}->{cdn} ) if $self->{cfg}->{cdn};
 
-    # create API object
-    $self->{api} = Pcore::App::API->new($self);
-
     return $self;
 };
 
@@ -93,15 +89,11 @@ sub default_cfg ($self) {
 
         # api
         api => {
-            backend => undef,
-            node    => {
-                workers => undef,
-                argon   => {
-                    argon2_time        => 3,
-                    argon2_memory      => '64M',
-                    argon2_parallelism => 1,
-                },
-            },
+            backend            => undef,
+            auth_workers       => undef,
+            argon2_time        => 3,
+            argon2_memory      => '64M',
+            argon2_parallelism => 1,
         },
     };
 
@@ -125,6 +117,13 @@ sub get_default_locale ( $self, $req ) {
 # RUN
 around run => sub ( $orig, $self ) {
 
+    # create API object
+    $self->{api} = P->class->load( 'API', ns => ref $self )->new( {
+        $self->{cfg}->{api}->%*,
+        app => $self,
+        db  => $self->{cfg}->{db},
+    } );
+
     # create node
     # TODO when to use node???
     if (1) {
@@ -134,7 +133,8 @@ around run => sub ( $orig, $self ) {
 
         my $requires = defined $node_req ? { $node_req->%* } : {};
 
-        $requires->{'Pcore::App::API::Node'} = undef if $self->{cfg}->{api}->{backend};
+        # TODO fix condition for all backend types, should be true for local backends
+        $requires->{'Pcore::App::API::Node'} = undef if $self->{api}->{db} && !defined $self->{api}->{backend};
 
         $self->{node} = Pcore::Node->new( {
             type     => ref $self,
@@ -268,7 +268,7 @@ sub get_nginx_vhost_params ( $self, $vhost_name ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 1                    | Modules::ProhibitExcessMainComplexity - Main code has high complexity score (21)                               |
+## |    3 | 1                    | Modules::ProhibitExcessMainComplexity - Main code has high complexity score (22)                               |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
